@@ -15,6 +15,7 @@ __all__ = [
     "BytetrackFromVideoOp",
     "VideoToFramesOp",
     "HaarFromFramesOp",
+    "StitchVideoOp",
     "QueryDatabaseOutputDataOp",
     "QueryDatabaseOutputStringOp",
 ]
@@ -43,6 +44,10 @@ HaarFromFramesOp = load_component_from_file(
     os.path.join(os.path.dirname(__file__), "haar_from_frames/component.yaml")
 )
 
+StitchVideosOp = load_component_from_file(
+    os.path.join(os.path.dirname(__file__), "stitch_videos/component.yaml")
+)
+
 QueryDatabaseOutputDataOp = load_component_from_file(
     os.path.join(os.path.dirname(__file__), "query_database_output_data/component.yaml")
 )
